#
# spec file for package python-grpcio-status
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global modname grpcio_status
%{?sle15_python_module_pythons}
Name:           python-grpcio-status
Version:        1.56.2
Release:        1.1
Summary:        Status proto mapping for gRPC
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://grpc.io
Source:         https://files.pythonhosted.org/packages/source/g/grpcio-status/grpcio-status-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-googleapis-common-protos >= 1.5.5
Requires:       python-grpcio >= %{version}
Requires:       python-protobuf >= 3.6.0
BuildArch:      noarch
%python_subpackages

%description
gRPC is a remote procedure call (RPC) framework. gRPC enables client
and server applications to communicate, and enables the building of
connected systems.

This package implements the GRPC Python status proto mapping.

%prep
%autosetup -p1 -n grpcio-status-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/grpc_status
%{python_sitelib}/%{modname}-%{version}.dist-info

%changelog
* Sat Aug  5 2023 munix9@googlemail.com
- Update to version 1.56.2:
  * [WRR] backport (gh#grpc/grpc#33694) to 1.56 (gh#grpc/grpc#33698)
  * [backport][iomgr][EventEngine] Improve server handling of
    file descriptor exhaustion (gh#grpc/grpc#33667)
- Switch build to pip/wheel.
- Add 'BuildArch: noarch'.
* Mon Jul  3 2023 Dirk Müller <dmueller@suse.com>
- update to 1.56.0:
  * Add type stub generation support to grpcio-tools.
  * [aio types] Fix some grpc.aio python types.
  * [Bazel Python3.11] Update Bazel dependencies for Python 3.11
  * Build native MacOS arm64 artifacts (universal2).
  * Build with System OpenSSL on Mac OS arm64.
  * Change Aio abort() function return type to NoReturn.
  * Change the annotated return type of UnaryStreamCall and StreamStreamCall from AsyncIterable to AsyncIterator.
  * De-experimentalize compression.
  * De-experimentalize wait-for-ready.
  * [EventEngine] Disable EventEngine polling in gRPC Python
  * Fix DeprecationWarning when calling asyncio.get_event_loop().
  * Fix lack of cooldown between poll attempts.
  * Include .pyi file.
  * Remove enum and future.
  * Remove references to deprecated syntax field.
  * [Remove Six] Remove dependency on six.
  * Respect CC variable in grpcio python build.
  * Revert "Build with System OpenSSL on Mac OS arm64
  * Support Python 3.11.
  * Support python 3.11 on aarch64.
  * Update xds-protos package to pull in protobuf 4.X.
* Sun Jul  2 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Apr  7 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.44.0
